@@ -5,10 +5,9 @@ url = pre_check("DeepLX")
 
 def translate(text, target_lang=user_lang.lower()):
     """翻译文本"""
-    if target_lang == 'en':
-        target_lang = 'en-us'
-    return requests.post(f"{url}/translate", json={
+    res = requests.post(f"{url}/translate", json={
         'text': text,
         'source_lang': 'auto',
         'target_lang': target_lang,
-    }).json()['data']
+    }).json()
+    return res.get('data')
